@@ -1,3 +1,5 @@
+import matplotlib
+matplotlib.use('agg')
 import pandas as pd
 import numpy as np
 from sklearn.model_selection import train_test_split
